RELEASES
========


`0.0.2 <https://github.com/Perceptua/indexia/releases/tag/v0.0.2>`_
-------------------------------------------------------------------

**Features:**

* Add 'zettelkasten' template to ``indexia.eidola.Templates``


`0.0.1 <https://github.com/Perceptua/indexia/releases/tag/v0.0.1>`_
-------------------------------------------------------------------

**Features:**

* ``eidola.Templates`` class to create sample data


`0.0.0 <https://github.com/Perceptua/indexia/releases/tag/v0.0.0>`_
-------------------------------------------------------------------

**Features:**

* ``indexia`` module to create & manage hierarchical data structures
* ``inquiry`` module to support dynamic SQL generation
* ``schemata`` module to create XML, dataframe, & network graph representations of indexia data
* ``eidola`` module to create sample indexia data